summary refs log tree commit diff
path: root/gnu/packages/hardware.scm
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2022-06-08 14:46:24 +0200
committerLudovic Courtès <ludo@gnu.org>2022-06-08 14:46:24 +0200
commit8c3e9da13a3c92a7db308db8c0d81cb474ad7799 (patch)
tree88d06952aa5cc3a9c4991d9c43eb7950ff174fe1 /gnu/packages/hardware.scm
parent5439c04ebdb7b6405f5ea2446b375f1d155a8d95 (diff)
parent0c5299200ffcd16370f047b7ccb187c60f30da34 (diff)
downloadguix-8c3e9da13a3c92a7db308db8c0d81cb474ad7799.tar.gz
Merge branch 'master' into core-updates
Diffstat (limited to 'gnu/packages/hardware.scm')
-rw-r--r--gnu/packages/hardware.scm108
1 files changed, 69 insertions, 39 deletions
diff --git a/gnu/packages/hardware.scm b/gnu/packages/hardware.scm
index 60b9a9f17b..d4e43feb06 100644
--- a/gnu/packages/hardware.scm
+++ b/gnu/packages/hardware.scm
@@ -1,11 +1,11 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2018–2021 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018–2022 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;; Copyright © 2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2020 Brice Waegeneire <brice@waegenei.re>
 ;;; Copyright © 2021 Evgeny Pisemsky <evgeny@pisemsky.com>
 ;;; Copyright © 2021 Léo Le Bouter <lle-bout@zaclys.net>
 ;;; Copyright © 2021 Denis Carikli <GNUtoo@cyberdimension.org>
-;;; Copyright © 2021 Petr Hodina <phodina@protonmail.com>
+;;; Copyright © 2021, 2022 Petr Hodina <phodina@protonmail.com>
 ;;; Copyright © 2021 Raghav Gururajan <rg@raghavgururajan.name>
 ;;; Copyright © 2021 Vinicius Monego <monego@posteo.net>
 ;;; Copyright © 2021, 2022 John Kehayias <john.kehayias@protonmail.com>
@@ -13,6 +13,7 @@
 ;;; Copyright © 2022 Maxime Devos <maximedevos@telenet.be>
 ;;; Copyright © 2022 Marius Bakke <marius@gnu.org>
 ;;; Copyright © 2022 Marcel Kupiec <formbi@protonmail.com>
+;;; Copyright © 2022 Maxim Cournoyer <maxim.cournoyer@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -34,6 +35,7 @@
   #:use-module (gnu packages admin)
   #:use-module (gnu packages autotools)
   #:use-module (gnu packages bash)
+  #:use-module (gnu packages bison)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages check)
   #:use-module (gnu packages cpp)
@@ -82,10 +84,37 @@
 ;; This is a module for packages related to physical hardware that don't (yet)
 ;; have a more specific home like gps.scm, security-token.scm, &c.
 
+
+(define-public envytools
+  (let ((commit "9014a51b1436461c7b3b005bdae72bf4912f4e72")
+        (revision "1"))
+    (package
+      (name "envytools")
+      (version (git-version "0.1" revision commit))
+      (home-page "https://github.com/envytools/envytools")
+      (source (origin
+                (method git-fetch)
+                (uri (git-reference
+                      (url home-page)
+                      (commit commit)))
+                (file-name (git-file-name name version))
+                (sha256
+                 (base32
+                  "1lqh73yxd5jgv7b770m37zimzhyn4f3053jybkixkhvm93zka8vd"))))
+      (build-system cmake-build-system)
+      (native-inputs (list bison flex pkg-config))
+      (inputs (list libxml2 python))
+      (synopsis "Reverse-engineering tools for Nvidia's proprietary GPU drivers")
+      (description
+       "This package provides tools for exploring Nvidia's proprietary GPU
+drivers, including an assembler and a disassembler for several GPU instruction
+sets, and tools to deal with register databases.")
+      (license license:expat))))
+
 (define-public hwinfo
   (package
     (name "hwinfo")
-    (version "21.80")
+    (version "21.81")
     (home-page "https://github.com/openSUSE/hwinfo")
     (source
      (origin
@@ -96,14 +125,14 @@
          (commit version)))
        (file-name (git-file-name name version))
        (sha256
-        (base32 "07058vjqdcd3la8y4b92f7fvcqxvmw1p0q4lg5kcn85pvbbg52ag"))
+        (base32 "0iyx1fb66s6b5ai4agw91nvl9wwk7z8g6y475vry3wv80dngzc43"))
        (modules
         '((guix build utils)))
        (snippet
         `(begin
            ;; Remove git2log program file.
            (delete-file "git2log")
-           ;; Remove variables that depends on git2log.
+           ;; Remove variables that depend on git2log.
            (substitute* "Makefile"
              (("GIT2LOG.*\\:=.*$") "")
              (("GITDEPS.*\\:=.*$") "")
@@ -113,7 +142,7 @@
              (lambda (port)
                (format port ,version)))))))
     (build-system gnu-build-system)
-    (outputs '("out" "dev" "doc"))
+    (outputs '("out" "lib" "doc"))
     (arguments
      `(#:tests? #f                      ; no test-suite available
        #:phases
@@ -121,10 +150,10 @@
          (add-after 'unpack 'patch
            (lambda* (#:key outputs #:allow-other-keys)
              (let* ((out (assoc-ref outputs "out"))
-                    (dev (assoc-ref outputs "dev"))
+                    (lib (assoc-ref outputs "lib"))
                     (doc (assoc-ref outputs "doc"))
-                    (incl-dir (string-append dev "/include"))
-                    (lib-dir (string-append dev "/lib"))
+                    (incl-dir (string-append lib "/include"))
+                    (lib-dir (string-append lib "/lib"))
                     (sbin-dir (string-append out "/sbin"))
                     (share-dir (string-append out "/share"))
                     (doc-dir (string-append doc "/share/doc")))
@@ -144,16 +173,16 @@
                  (("/usr/sbin") sbin-dir)
                  (("/usr/share") share-dir)
                  (("\\$\\(DESTDIR\\)/sbin ") ""))
-               ;; Add output "dev" to the run-path.
+               ;; Add the "lib" output to the run-path.
                (substitute* "Makefile.common"
                  (("-Lsrc")
                   (string-append "-Lsrc " "-Wl,-rpath=" lib-dir)))
                ;; Correct program name of the lexical analyzer.
                (substitute* "src/isdn/cdb/Makefile"
                  (("lex isdn_cdb.lex") "flex isdn_cdb.lex"))
                ;; Patch pkgconfig file to point to output "dev".
                (substitute* "hwinfo.pc.in"
-                 (("/usr") dev)))))
+                 (("/usr") lib)))))
          (delete 'configure)
          (replace 'build
            (lambda _
@@ -242,14 +271,14 @@ RGB animations.")
 (define-public ddcutil
   (package
     (name "ddcutil")
-    (version "1.2.1")
+    (version "1.2.2")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "https://www.ddcutil.com/tarballs/"
                            "ddcutil-" version ".tar.gz"))
        (sha256
-        (base32 "0fp7ffjn21p0bsc5b1ipf3dbpzwn9g6j5dpnwdnca052ifzk2w7i"))))
+        (base32 "18fbd45h2r3r702dvmlmyrwgs3ymr4mhm4f12lgv9jqb5csalbw2"))))
     (build-system gnu-build-system)
     (native-inputs
      (list pkg-config))
@@ -286,7 +315,7 @@ calibrated, and restored when the calibration is applied.")
 (define-public ddcui
   (package
     (name "ddcui")
-    (version "0.1.2")
+    (version "0.2.1")
     (source
      (origin
        (method git-fetch)
@@ -295,7 +324,7 @@ calibrated, and restored when the calibration is applied.")
              (commit (string-append "v" version))))
        (file-name (git-file-name name version))
        (sha256
-        (base32 "0myma1zw6dlygv3xbin662d91zcnwss10syf12q2fppkrd8qdgqf"))))
+        (base32 "0a9xfv80dpimx9wi9igjbbfydyfsgnbk6dv1plhjzyp2a9shdibb"))))
     (build-system cmake-build-system)
     (arguments
      '(#:tests? #f))                    ; No test suite
@@ -348,39 +377,40 @@ human-readable format and checks if it conforms to the standards.")
       (license license:expat))))
 
 (define-public h-client
-  (let ((version "0.0a0")
-        (revision 138))
+  (let ((commit "63ff4a3bf9c3c3b6297091e08192d34991465431")
+        (revision "0"))
     (package
       (name "h-client")
-      (version (string-append version "-" (number->string revision)))
+      (version (git-version "0.0a0" revision commit))
       (source
        (origin
-         (method svn-fetch)
-         (uri
-          (svn-reference
-           (url "https://svn.savannah.nongnu.org/svn/h-client/trunk/h-client")
-           (revision revision)))
+         (method git-fetch)
+         (uri (git-reference
+               ;; Use this Python 3 fork until the changes have been reviewed
+               ;; and integrated into the official Savannah repository (in
+               ;; progress).
+               (url "https://git.sr.ht/~apteryx/h-client")
+               (commit commit)))
          (file-name (git-file-name name version))
          (sha256
-          (base32 "1pdd2qhyaa5vh7z4rkpwjlby1flkwhzmp8zlglalx5y5sv95l4kp"))))
+          (base32 "0c6s96a1zmsnn7bnfhm790c1fr8sid0zdyh9mwig4y6ffn83czh5"))))
       (build-system python-build-system)
-      (arguments
-       `(#:python ,python-2
-         ;; Tests depends on /etc/os-release which does not exist in the
-         ;; build container.
-         #:tests? #f))
       (inputs
-       (list python-2 python2-pycurl python2-pygtk pciutils usbutils))
-      (synopsis "Graphical client for the h-node hardware database
-project")
+       (list gdk-pixbuf
+             gtk+
+             pciutils
+             python-pycurl
+             python-pygobject
+             usbutils))
+      (synopsis "Graphical client for the h-node hardware database project")
       (description
        "The h-node project (https://www.h-node.org) aims to build a database of
-hardware that works with fully free operating systems.
-h-client is a GTK+ graphical client that is able to retrieves information on
-the hardware inside the computer it's running on, and on peripherals connected
-to it, and help you submit that information to the h-node project along with
-whether the hardware works with a fully free operating system or not.")
-      (home-page "https://savannah.nongnu.org/projects/h-client/")
+hardware that works with fully free operating systems.  h-client is a GTK+
+graphical client that is able to retrieves information on the hardware inside
+the computer it's running on, and on peripherals connected to it, and helps
+you submit that information to the h-node project along with whether the
+hardware works with a fully free operating system or not.")
+      (home-page "https://savannah.nongnu.org/projects/h-source/")
       (license license:gpl3+))))
 
 (define-public headsetcontrol
@@ -144,16 +173,16 @@
                (substitute* "src/isdn/cdb/Makefile"
                  (("lex isdn_cdb.lex") "flex isdn_cdb.lex"))
-               ;; Patch pkgconfig file to point to output "dev".
+               ;; Patch pkg-config file to point to the "lib" output.
                (substitute* "hwinfo.pc.in"